Applies accelerated proximal gradient algorithm (with backtracking) to the l1-regularized quadratic program $$f(\mathbf{x}) + g(\mathbf{x}) = \frac{1}{2}\mathbf{x}^TA\mathbf{x} - d^T\mathbf{x} + \lambda |\mathbf{x}|_1$$
APG_EN2bt(
A,
Xt,
Om,
gamma,
d,
x0,
lam,
L,
eta,
maxits,
tol,
selector = rep(1, dim(x0)[1])
)APG_EN2bt returns an object of class "APG_EN2bt" including a list
with the following named components
callThe matched call.
xFound solution.
kNumber of iterations used.
p by p positive definite coefficient matrix $$A = (\gamma Om + X^T X/n)$$.
Same as X above, we need it to make calculations faster.
Same reason as for the above parameter.
l2 regularizing parameter.
nx1 dimensional column vector.
Regularization parameter for l1 penalty, must be greater than zero.
Initial vlaue of the backtracking Lipshitz constant.
Backtracking scaling parameter.
Number of iterations to run
Stopping tolerance for proximal gradient algorithm.
Vector to choose which parameters in the discriminant vector will be used to calculate the regularization terms. The size of the vector must be *p* the number of predictors. The default value is a vector of all ones. This is currently only used for ordinal classification.
This function is used by other functions and should only be called explicitly for debugging purposes.
Used by: SDAAP and the SDAAPcv cross-validation version.