Applies accelerated proximal gradient (with backtracking) algorithm to the l1-regularized quadratic program $$f(\mathbf{x}) + g(\mathbf{x}) = \frac{1}{2}\mathbf{x}^TA\mathbf{x} - d^T\mathbf{x} + \lambda |\mathbf{x}|_1$$
prox_ENbt(A, Xt, Om, gamma, d, x0, lam, L, eta, maxits, tol)prox_ENbt returns an object of class "prox_ENbt" including a list
with the following named components
callThe matched call.
xFound solution.
kNumber of iterations used.
p by p positive definite coefficient matrix $$A = (\gamma Om + X^T X/n)$$.
Same as X above, we need it to make calculations faster.
Same reason as for the above parameter.
l2 regularizing parameter.
nx1 dimensional column vector.
Regularization parameter for l1 penalty, must be greater than zero.
Initial value of backtracking Lipshitz constant.
Backtracking scaling parameter.
Number of iterations to run
Stopping tolerance for proximal gradient algorithm.
This function is used by other functions and should only be called explicitly for debugging purposes.
Used by: SDAP and the SDAPcv cross-validation version.